==> progamification-0.0.45.tar.gz: lib/src/services/gamification.service.dart <==
import 'package:progamification/progamification.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/services/auth.service.dart';
import 'package:progamification/src/services/leaderboard.service.dart';
import 'package:progamification/src/services/pro_gamfication.service.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:progamification/src/services/user.service.dart';
import 'package:get/get.dart';
import 'package:shared_preferences/shared_preferences.dart';

class GamificationService {
  Future<bool> init(String clientId, String clientSecret, String userId,
      String applicationId) async {
    try {
      Get.put<GamificationAuthService>(GamificationAuthService(),
          permanent: true);
      Get.put<GamificationStorageService>(GamificationStorageService(),
          permanent: true);
      Get.put<SasTokenService>(SasTokenService(), permanent: true);
      GamificationStorageService.setString('userId', userId);
      GamificationStorageService.setString('applicationId', applicationId);
      bool access = await GamificationAuthService.checkAccess();
      if (!access) {
        await GamificationAuthService.init(clientId, clientSecret);
      }
      Get.put<LeaderBoardService>(LeaderBoardService(), permanent: true);
      Get.put<UserService>(UserService(), permanent: true);
      Get.put<LeaderBoardController>(LeaderBoardController(), permanent: true);
      return true;
    } catch (e) {
      return false;
    }
  }

  static updateGameAction(String userId, String gameActionId,
      String correspondingUserId, String correspondingUserApplicationId) async {
    ProGamificationService().addPointsToUser({
      "userId": userId,
      "gameActionId": gameActionId,
      "correspondingUserId": correspondingUserId,
      "correspondingUserApplicationId": correspondingUserApplicationId
    });
    SharedPreferences preferences = await SharedPreferences.getInstance();
    String? appId = preferences.getString('applicationId');
    LeaderBoardController leaderBoardController =
        Get.find<LeaderBoardController>();
    leaderBoardController.getData(userId, appId!);
    leaderBoardController.getRewards(userId, appId);
  }

  static addUser(GamifiedUser user) async {
    return await UserService().addUser(user);
  }
}

==> progamification-0.0.49.tar.gz: lib/src/services/gamification.service.dart <==
import 'package:progamification/progamification.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/services/auth.service.dart';
import 'package:progamification/src/services/leaderboard.service.dart';
import 'package:progamification/src/services/pro_gamfication.service.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:progamification/src/services/user.service.dart';
import 'package:get/get.dart';
import 'package:shared_preferences/shared_preferences.dart';

class GamificationService {
  static Future<bool> init(String clientId, String clientSecret, String userId,
      String applicationId) async {
    try {
      Get.put<GamificationAuthService>(GamificationAuthService(),
          permanent: true);
      Get.put<GamificationStorageService>(GamificationStorageService(),
          permanent: true);
      Get.put<SasTokenService>(SasTokenService(), permanent: true);
      GamificationStorageService.setString('userId', userId);
      GamificationStorageService.setString('applicationId', applicationId);
      bool access = await GamificationAuthService.checkAccess();
      if (!access) {
        await GamificationAuthService.init(clientId, clientSecret);
      }
      Get.put<LeaderBoardService>(LeaderBoardService(), permanent: true);
      Get.put<UserService>(UserService(), permanent: true);
      Get.put<LeaderBoardController>(LeaderBoardController(), permanent: true);
      return true;
    } catch (e) {
      return false;
    }
  }

  static updateGameAction(String userId, String gameActionId,
      String correspondingUserId, String correspondingUserApplicationId) async {
    ProGamificationService().addPointsToUser({
      "userId": userId,
      "gameActionId": gameActionId,
      "correspondingUserId": correspondingUserId,
      "correspondingUserApplicationId": correspondingUserApplicationId
    });
    // SharedPreferences preferences = await SharedPreferences.getInstance();
    // String? appId = preferences.getString('applicationId');
    // LeaderBoardController leaderBoardController =
    //     Get.find<LeaderBoardController>();
    // leaderBoardController.getData(userId, appId!);
    // leaderBoardController.getRewards(userId, appId);
  }

  static addUser(GamifiedUser user) async {
    return await UserService().addUser(user);
  }
}
